# estare
𐎠𐎿𐎫𐎼

[![Python application](https://github.com/soheil-soltani/estare/actions/workflows/ci.yml/badge.svg?branch=master_pre_stage)](https://github.com/soheil-soltani/estare/actions/workflows/ci.yml)
